<template>
    <section class="py-3 mb-5">
        <span class="d-block mb-5">Home/Profile</span>
        <form @submit.prevent="updateProfile">
            <div class="row flex-column-reverse flex-md-row mb-4">
                <div class="col-md-6">
                    <div class="theme-shadow p-4 rounded">
                        <div class="mb-3">
                            <label class="form-label fs-5">Name</label>
                            <input type="text" class="form-control bg-light border-0" placeholder="Full Name"
                                v-model="form.name">
                        </div>
                        <div class="mb-3">
                            <label class="form-label fs-5">Phone</label>
                            <input type="text" class="form-control bg-light border-0" placeholder="+8801XXXXXXXXX"
                                v-model="form.phone">
                        </div>
                        <div class="mb-3">
                            <label class="form-label fs-5">Email</label>
                            <input autocomplete="username" type="email" class="form-control bg-light border-0"
                                placeholder="user@example.com" v-model="form.email">
                        </div>
                        <div class="mb-3">
                            <label class="form-label fs-5">Current Password</label>
                            <input autocomplete="current-password" type="password"
                                class="form-control bg-light border-0" placeholder="Enter current password to change"
                                v-model="form.current_password">
                        </div>
                        <div class="mb-3">
                            <label class="form-label fs-5">Password</label>
                            <input autocomplete="new-password" type="password" class="form-control bg-light border-0"
                                placeholder="Enter new password to change" v-model="form.password">
                        </div>
                        <div class="mb-3">
                            <label class="form-label fs-5">Confirm Password</label>
                            <input autocomplete="new-password" type="password" class="form-control bg-light border-0"
                                placeholder="Confirm new password" v-model="form.password_confirmation">
                        </div>
                    </div>
                </div>

                <div class="col-md-6 mb-5 mb-md-0">
                    <div class="theme-shadow p-5 rounded d-flex h-100 align-items-center">
                        <div class="w-100">
                            <img :src="profilePhoto ? profilePhoto : authStore.userData.profile_picture"
                                alt="Profile picture" height="250px" width="250px"
                                class="rounded-circle mx-auto object-fit-cover d-block border border-3 border-primary mb-4">
                            <input id="upload-pp" type="file" class="d-none" @change="changeProfilePhoto">
                            <label for="upload-pp" class="upload-pp-btn btn btn-outline-primary border-2 w-100">
                                Upload image
                            </label>
                        </div>
                    </div>
                </div>
            </div>
            <button type="submit" class="btn btn-primary w-100">Save</button>
        </form>
    </section>
</template>

<style lang="scss" scoped>
.upload-pp-btn {
    border-style: dashed;
}
</style>

<script setup>
import { useAuthStore } from '@/stores/auth'
import { ref } from 'vue'
import Swal from 'sweetalert2'

const authStore = useAuthStore()

// Initialize form data
const form = ref({
    name: authStore.userData.name,
    phone: authStore.userData.phone,
    email: authStore.userData.email,
    current_password: null,
    password: null,
    password_confirmation: null,
    profile_picture: null
})

// Handle form submission
const updateProfile = async () => {
    try {
        let formData = new FormData()
        formData.append('name', form.value.name)
        formData.append('phone', form.value.phone)

        if (form.value.profile_picture) formData.append('profile_picture', form.value.profile_picture)
        if (form.value.current_password || form.value.password || form.value.password_confirmation) {
            formData.append('current_password', form.value.current_password)
            formData.append('password', form.value.password)
            formData.append('password_confirmation', form.value.password_confirmation)
        }

        if (form.value.email) formData.append('email', form.value.email)

        // API request to update the profile
        const response = await axios.post(`/profile/update`, formData, {
            headers: {
                'Accept': 'application/json',
                'Authorization': 'Bearer ' + authStore.authToken
            }
        })

        // Update user data in state
        authStore.setAuthData(response.data.data.token, response.data.data.user)

        Swal.fire({
            icon: 'success',
            title: 'Success',
            text: 'Profile updated successfully',
            showConfirmButton: false,
            timer: 1500
        })
    } catch (error) {
        console.log(error)
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: error.response._data.message,
            showConfirmButton: false,
            timer: 1500
        })
    }
}

const profilePhoto = ref(false)
let changeProfile = ref(false)

const changeProfilePhoto = (event) => {
    profilePhoto.value = URL.createObjectURL(event.target.files[0]);
    form.value.profile_picture = event.target.files[0];
    changeProfile.value = true;
}
</script>
